@@ -1,12 +1,13 @@
 require 'spec_helper'
 
 describe 'tacker::policy' do
-
-  shared_examples_for 'tacker policies' do
+  shared_examples 'tacker::policy' do
     let :params do
       {
-        :policy_path => '/etc/tacker/policy.json',
-        :policies    => {
+        :enforce_scope        => false,
+        :enforce_new_defaults => false,
+        :policy_path          => '/etc/tacker/policy.yaml',
+        :policies             => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
             'value' => 'foo:bar'
@@ -17,26 +18,29 @@ describe 'tacker::policy' do
 
     it 'set up the policies' do
       is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
-        :key        => 'context_is_admin',
-        :value      => 'foo:bar',
-        :file_user  => 'root',
-        :file_group => 'tacker',
+        :key         => 'context_is_admin',
+        :value       => 'foo:bar',
+        :file_user   => 'root',
+        :file_group  => 'tacker',
+        :file_format => 'yaml',
       })
       is_expected.to contain_oslo__policy('tacker_config').with(
-        :policy_file => '/etc/tacker/policy.json',
+        :enforce_scope        => false,
+        :enforce_new_defaults => false,
+        :policy_file          => '/etc/tacker/policy.yaml',
       )
     end
   end
 
   on_supported_os({
-    :supported_os   => OSDefaults.get_supported_os
+    :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'tacker policies'
+      it_behaves_like 'tacker::policy'
     end
   end
 end
